==> dde-shell_2.0.15.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_uk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="uk">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>WLAN увімкнено</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>WLAN вимкнено</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>Caps Lock увімкнено</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>Caps Lock вимкнено</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>Цифрову панель увімкнено</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>Цифрову панель вимкнено</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>Сенсорну панель увімкнено</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>Сенсорну панель вимкнено</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>Перемикач сенсорної панелі</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Перемикач Fn</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>Режим польоту увімкнено</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>Режим польоту вимкнено</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>Збалансоване живлення</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>Заощадження енергії</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>Висока швидкодія</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>Ефект вікна увімкнений</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>Ефект вікна вимкнений</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>Не вдалося увімкнути ефекти вікон</translation>
    </message>
    <message>
        <source>Microphone off</source>
        <translation>Вимкнути мікрофон</translation>
    </message>
    <message>
        <source>Microphone on</source>
        <translation>Увімкнути мікрофон</translation>
    </message>
</context>
</TS>

==> dde-shell_2.0.19.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_uk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="uk">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>WLAN увімкнено</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>WLAN вимкнено</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>Caps Lock увімкнено</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>Caps Lock вимкнено</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>Цифрову панель увімкнено</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>Цифрову панель вимкнено</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>Сенсорну панель увімкнено</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>Сенсорну панель вимкнено</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>Перемикач сенсорної панелі</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Перемикач Fn</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>Режим польоту увімкнено</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>Режим польоту вимкнено</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>Збалансоване живлення</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>Заощадження енергії</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>Висока швидкодія</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>Ефект вікна увімкнений</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>Ефект вікна вимкнений</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>Не вдалося увімкнути ефекти вікон</translation>
    </message>
    <message>
        <source>Microphone off</source>
        <translation>Вимкнути мікрофон</translation>
    </message>
    <message>
        <source>Microphone on</source>
        <translation>Увімкнути мікрофон</translation>
    </message>
    <message>
        <source>Camera on</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Camera off</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
